summaryrefslogtreecommitdiff
path: root/scrypt.h
diff options
context:
space:
mode:
authorJeffrey Walton <noloader@gmail.com>2019-08-16 07:12:14 -0400
committerJeffrey Walton <noloader@gmail.com>2019-08-16 07:12:14 -0400
commite22700f741af9071b166a74dd904a1bb7910c6b9 (patch)
treea743990feaa3aa5735dc3475e1acdca2800c2215 /scrypt.h
parentc0a5a06a8285c515336a7540095d75aaad628644 (diff)
downloadcryptopp-git-e22700f741af9071b166a74dd904a1bb7910c6b9.tar.gz
Fix use of MaxDerivedKeyLength (GH #874)
Diffstat (limited to 'scrypt.h')
-rw-r--r--scrypt.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/scrypt.h b/scrypt.h
index 8c6f394f..37c0161d 100644
--- a/scrypt.h
+++ b/scrypt.h
@@ -45,8 +45,8 @@ public:
}
// KeyDerivationFunction interface
- size_t MaxDerivedLength() const {
- return static_cast<size_t>(-1);
+ size_t MaxDerivedKeyLength() const {
+ return static_cast<size_t>(0)-1;
}
// KeyDerivationFunction interface
@@ -67,7 +67,7 @@ public:
/// \param blockSize the block size
/// \param parallelization the parallelization factor
/// \returns the number of iterations performed
/// \throws InvalidDerivedLength if <tt>derivedLen</tt> is invalid for the scheme
/// \details DeriveKey() provides a standard interface to derive a key from
/// a seed and other parameters. Each class that derives from KeyDerivationFunction
/// provides an overload that accepts most parameters used by the derivation function.
@@ -67,7 +67,7 @@ public:
/// \param parallelization the parallelization factor
/// \returns the number of iterations performed
- /// \throws InvalidDerivedLength if <tt>derivedLen</tt> is invalid for the scheme
+ /// \throws InvalidDerivedKeyLength if <tt>derivedLen</tt> is invalid for the scheme
/// \details DeriveKey() provides a standard interface to derive a key from
/// a seed and other parameters. Each class that derives from KeyDerivationFunction